@@ -10,7 +10,21 @@
         enumSample()		monte carlo sampling of outcomes
 
    Michael Maurer, Apr 2002
-*/
+
+ *  This package is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 dated June, 1991.
+ *
+ *  This package is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this package; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
+ */
 
 #include <stdio.h>
 #include <string.h>
@@ -742,7 +756,7 @@ enumResultAlloc(enum_result_t *result, int nplayers,
   result->ordering->mode = mode;
   result->ordering->nplayers = nplayers;
   result->ordering->nentries = nentries;
-  result->ordering->hist = (int *) calloc(nentries, sizeof(int));
+  result->ordering->hist = (unsigned int *) calloc(nentries, sizeof(int));
   if (result->ordering->hist == NULL) {
     free(result->ordering);
     result->ordering = NULL;
