@@ -1,7 +1,7 @@
 /*
  *  Copyright 2006 Michael Maurer <mjmaurer@yahoo.com>, 
  *                 Brian Goetz <brian@quiotix.com>, 
- *                 Loic Dachary <loic@gnu.org>, 
+ *                 Loic Dachary <loic@dachary.org>, 
  *                 Tim Showalter <tjs@psaux.com>
  *
  *  This package is free software; you can redistribute it and/or modify
@@ -110,7 +110,7 @@ MakeTable_outputUInt64(uint64 arg) {
 #if defined(MSDOS)
   sprintf(buf, " { 0x%08x%08x } ", high, low);
 #else
-#ifdef WIN32
+#if defined(WIN32) && !defined(__MINGW32__)
   sprintf(buf, " { 0x%08x%08xi64 } ", high, low);
 #else
   sprintf(buf, " { 0x%08x%08xLL } ", high, low);
